// NP-HD2IP Matrix Selector
//
// (C) 2018 Arvanics Corporation.

const netaddr = "192.168.70."  // ネットワークアドレス(サブネットアドレス)
const rx1ip4 = 101;            // RX1 のホストアドレス
const tx1ip4 = 201;            // TX1 のホストアドレス
const tx1ch = 1;               // TX1 のチャンネル番号

// 入力の名前と数。
// number_of_txs を減らすとボタンが消える。
const inputs = [
  "BDプレーヤ",
  "Mac mini",
  "Dell PC",
  "入力4",
  "DVDプレーヤ",
  "天井カメラ",
  "入力7",
  "入力8",
  "入力9",
  "入力10",
];
const number_of_txs = 6;

// 出力の名前と数。
// number_of_ogps を減らすとボタンが消える。
const outputs = [
  "プロジェクター1",
  "ウォール左上",
  "ウォール右上",
  "ウォール左下",
  "ウォール右下",
  "Panasonic TV1",
  "Panasonic TV2",
  "制御卓ディスプレイ",
  "出力8",
  "出力9",
  "出力10",
];
const number_of_ogps = 7;

// 出力のグループ化は無し
const ogps = [ [1], [2], [3], [4], [5], [6], [7], [8], [9], [10] ];

// 2x2ウォールの受信機番号と設定パラメータ。
// 受信機番号と setup_vw2 コマンドの引数をデータとして登録。
// 下記の例はベゼルコンペが無い場合
const wall_param =  [
 [2, "0+0+5000+5000+0"],
 [3, "5000+0+10000+5000+0"],
 [4, "0+5000+5000+10000+0"],
 [5, "5000+5000+10000+10000+0"], ];
const number_of_wall_elements = 4;

// プリセットボタンの名前。
// 長さ0の文字列にするとボタンが消える
const preset_label = [
  "パターン１",
  "パターン２",
  "パターン３",
  "ウォール構成",
  "送信器 HPD",
  "全て再起動",
  "シリアル出力",
  "リレーON",
];
const number_of_presets = 8;  // 変更禁止

//////////////////////////////////////////////////////////////////////
//
// プリセットボタンで実行する内容の定義
//
// hd2ip-matrix.js で定義された以下の関数を利用している
// 
// チャンネル変更
// setCH(出力グループ番号, チャンネル)                            
//
// ウォール構成/解除
// wallOn() / wallOff()
//
// プリセットボタンラベル変更
// setPresetLabel(プリセット番号, ラベル)
//
// コマンド送信
// sendCommand(IPアドレス, コマンド文字列, コールバック関数)
//
// IPアドレス計算
// get_ip(tx11ip4 または rx1ip4, 受信機番号または送信機番号)
//

async function preset1() {
  // 7台のチャンネルを一気に変更
  setCH(1, 1);
  setCH(2, 2);
  setCH(3, 2);
  setCH(4, 2);
  setCH(5, 2);
  setCH(6, 3);
  setCH(7, 4);
}

async function preset2() {
  // 7台のチャンネルを一気に変更
  setCH(1, 6);
  setCH(2, 5);
  setCH(3, 5);
  setCH(4, 5);
  setCH(5, 5);
  setCH(6, 4);
  setCH(7, 3);
}

async function preset3() {
  // 7台のチャンネルを一気に変更
  setCH(1,  3);
  setCH(2,  6);
  setCH(3,  6);
  setCH(4,  6);
  setCH(5,  6);
  setCH(6,  5);
  setCH(7,  4);
}

let wall_on = false;
async function preset4() {
  // ウォール構成・解除
  // プリセットボタンのトグル動作・ボタン表示の動的変更例

  if (wall_on) {
    wallOff();
    setPresetLabel(4, "ウォール構成");
  }
  else {
    wallOn();
    setPresetLabel(4, "ウォール解除");
  }
  wall_on = !wall_on;
}

async function preset5() {
  // TX にEDIDを設定するとソース機器に対して HPD が出る
  // ので、ケーブルの抜き差しと同等となる
  for (i = 1; i <= number_of_txs; i++) {
    sendCommand(get_ip(tx1ip4, i), "set_edid+hdmihd", null);
  }
}

async function preset6() {
  // RX1に4秒OSD表示した後に全ての送受信機を再起動。
  // 4秒待つために await をつけて sendCommand() を呼ぶ(同期実行)
  //
  // await を付けないで sendCommand() を呼ぶと、コマンドを発行
  // するだけでその終了を待たずに関数が終了する(非同期実行)
  // 複数を対象とする場合に、ほぼ同時にコマンド発行が可能となる。
  //
  // await を付けている例はここだけ。
  await sendCommand(get_ip(rx1ip4, 1), "set_osd2+4+Reboot+All", null);

  for (i = 1; i <= number_of_txs; i++) {
    sendCommand(get_ip(tx1ip4, i), "reboot", null);
  }
  for (i = 0; i < number_of_ogps; i++) {
    for (let n of ogps[i]) {
      sendCommand(get_ip(rx1ip4, n), "reboot", null);
    }
  }
}

async function preset7() {
  // RX1 からシリアル出力
  // OSD 表示終了を待たずにシリアル出力
  sendCommand(get_ip(rx1ip4, 1), "set_osd2+2+Serial+Out", null);
  sendCommand(get_ip(rx1ip4, 1), "http2serial+100+CRLF+Hello+World", null);
}

let relay_on = false;
async function preset8() {
  // Aurora LXC-1 リレーON/OFF
  // プリセットボタンのトグル動作・ボタン表示の動的変更例

  if (relay_on) {
    sendCommand(get_ip(rx1ip4, 1), "http2lxc+192.168.70.31+200+set+relay+1+OFF", null);
    setPresetLabel(8, "リレーON");
  }
  else {
    sendCommand(get_ip(rx1ip4, 1), "http2lxc+192.168.70.31+200+set+relay+1+ON", null);
    setPresetLabel(8, "リレーOFF");
  }
  relay_on = !relay_on;
}
