// NP-HD2IP Matrix Selector
//
// (C) 2018 Arvanics Corporation.

const netaddr = "192.168.70."  // ネットワークアドレス(サブネットアドレス)
const rx1ip4 = 101;            // RX1 のホストアドレス
const tx1ip4 = 201;            // TX1 のホストアドレス
const tx1ch = 1;               // TX1 のチャンネル番号

// 入力の名前と数。
// number_of_txs を減らすとボタンが消える。
const inputs = [
  "入力1",
  "入力2",
  "入力3",
  "入力4",
  "入力5",
  "入力6",
  "入力7",
  "入力8",
  "入力9",
  "入力10",
];
const number_of_txs = 6;

// 出力の名前と数。
// number_of_ogps を減らすとボタンが消える。
const outputs = [
  "出力1",
  "出力2",
  "出力3",
  "出力4",
  "出力5",
  "出力6",
  "出力7",
  "出力8",
  "出力9",
  "出力10",
];
const number_of_ogps = 6;

// 出力のグルーピング
// 同一出力グループ内の複数のRXに対して同期したチャンネル切り替えをおこなう。
// RX の指定は 1 始まりの連続番号とする。
// 番号の差分がIPアドレスのホスト部分の数字の差分と一致させる。
// 「出力の数」と「出力グループの数」は同じものとみなす。
//
// 通常の場合は 1 出力 1 RX となる。各「出力グループ」内に RX が 1 台だけ。
// const ogps = [ [1], [2], [3], [4], [5], [6], [7], [8], [9], [10] ];
//
// 1「出力グループ」ごとに RX が 2 台ある場合の例
// const ogps = [
//   [ 1,  2], [ 3,  4], [ 5,  6], [ 7,  8], [ 9, 10],
//   [11, 12], [13, 14], [15, 16], [17, 18], [19, 20],
// ];
//
const ogps = [ [1], [2], [3], [4], [5], [6], [7], [8], [9], [10] ];

// ウォール設定
//
const wall_param =  [];
const number_of_wall_elements = 0;

// プリセットボタンの名前。
// 長さ0の文字列にするとボタンが消える
const preset_label = [
  "プリセット1",
  "プリセット2",
  "プリセット3",
  "プリセット4",
  "プリセット5",
  "プリセット6",
  "",
  "",
];
const number_of_presets = 8;  // 変更禁止

//////////////////////////////////////////////////////////////////////
//
// プリセットボタンで実行する内容の定義
//
// 全ての受信器に対してOSD表示コマンドを発行する例
// hd2ip-matrix.js で定義された以下の関数を利用している
//
// コマンド送信
// sendCommand(IPアドレス, コマンド文字列, コールバック関数)
//
// IPアドレス計算
// get_ip(tx11ip4 または rx1ip4, 受信機番号または送信機番号)
//


async function preset1() {
  // 非同期呼び出しの例
  // 全ての受信器でほぼ同時にOSD表示が始まる
  // 2秒のOSD表示が終わってからコールバックされる
  for (let i = 0; i < number_of_ogps; i++) 
    for (let n of ogps[i]) {
      sendCommand(get_ip(rx1ip4, n), "set_osd2+2+" + n + "+P1", function() {
        console.log("sendCommand() callback: " + n);
      });
    }
}

async function preset2() {
  // 同期呼び出しの例
  // OSD表示が消えてコマンドが完了するまで、次の受信器へコマンドが
  // 発行されない
  for (let i = 0; i < number_of_ogps; i++)
    for (let n of ogps[i]) 
      await sendCommand(get_ip(rx1ip4, n), "set_osd2+2+" + n + "+P2", null);
}

async function preset3() {
  for (let i = 0; i < number_of_ogps; i++)
    for (let n of ogps[i])
      sendCommand(get_ip(rx1ip4, n), "set_osd2+2+" + n + "+P3", null);
}

async function preset4() {
  for (let i = 0; i < number_of_ogps; i++)
    for (let n of ogps[i])
      sendCommand(get_ip(rx1ip4, n), "set_osd2+2+" + n + "+P4", null);
}

async function preset5() {
  for (let i = 0; i < number_of_ogps; i++)
    for (let n of ogps[i])
      sendCommand(get_ip(rx1ip4, n), "set_osd2+2+" + n + "+P5", null);
}

async function preset6() {
  for (let i = 0; i < number_of_ogps; i++)
    for (let n of ogps[i])
      sendCommand(get_ip(rx1ip4, n), "set_osd2+2+" + n + "+P6", null);
}

async function preset7() {
  for (let i = 0; i < number_of_ogps; i++)
    for (let n of ogps[i])
      sendCommand(get_ip(rx1ip4, n), "set_osd2+2+" + n + "+P7", null);
}

async function preset8() {
  for (let i = 0; i < number_of_ogps; i++)
    for (let n of ogps[i])
      sendCommand(get_ip(rx1ip4, n), "set_osd2+2+" + n + "+P8", null);
}
