/////////////////////////////////////////////////////////////////////
//
//  NP-HD2IP Matrix Selector
//
//  (C) 2018 Arvanics Corporation.
//

// Return true in case of checking only GUI.
// You can override behavior of this function in config.js.
// config.js would be read after this in index.html.
//
function suppress_send_command(ip) { return false; }

const btnrows          =  10;
let   input            =  0;
let   wall_member      = [0,0,0,0,0,0,0,0,0,0];
let   rx_output_status = [1,1,1,1,1,1,1,1,1,1];

function sendCommand(ip, cmd, callback) {
  const uri = "http://" + ip + "/cgi-bin/query.cgi?cmd=" + cmd;
  console.log("sendCommand(), uri:" + uri);

  if (suppress_send_command(ip)){console.log("command suppressed");return;}

  const p = new Promise((resolve, reject) => {

    const xhr = new XMLHttpRequest();
    xhr.open("GET", uri, true);
    xhr.timeout = 5000;
    xhr.onload = function(e) {
      if (xhr.status === 200) {
        console.log('xhr.response: ' + ip + ' ' + cmd + ' ' + xhr.responseText + '\n');
        if (callback) callback(xhr.responseText);
      }
      resolve(xhr);
    }
    xhr.onerror = function(e) {
      console.log('error xhr.status: ' + xhr.status + '\n');
      resolve(xhr);
    }
    xhr.ontimeout = function(e) {
      console.log('xhr.ontimeout: ' + ip + " " + cmd);
      xhr.abort();
      resolve(xhr);
    }

    xhr.send();
  });
  return p;
}

function get_ip(ip4, n) {
  return netaddr + (ip4 + n - 1);
}

function checkRadio(n) {
  input = Number(n);
}

async function wallOff() {
  const cmd = "setup_vw2+0+0+10000+10000+0";

  for (let i = 0; i < number_of_wall_elements; i++) {
    //await sendCommand(rx, cmd, null);
    sendCommand(get_ip(rx1ip4, wall_param[i][0]), cmd, null);
    wall_member[wall_param[i][0] - 1] = 0;
  }
}

async function wallOn() {
  for (let i = 0; i < number_of_wall_elements; i++) {
    sendCommand(get_ip(rx1ip4, wall_param[i][0]), "setup_vw2+" + wall_param[i][1], null);
    wall_member[wall_param[i][0] - 1] = 1;
  }
}

function setChannelLabel(rx, ch) {
  let btn = document.getElementById("btn_in_" + rx);
  if (ch) btn.textContent = inputs[ch - 1] + " →";
  else    btn.textContent = "停止";
}

function setCH(rx, ch) {
  let btn = document.getElementById("btn_in_" + rx);
  if (ch) {
    for (let n of ogps[rx - 1])
      if (n) sendCommand(get_ip(rx1ip4, n), "set_channel+" + (ch + tx1ch - 1), null);

    if (rx_output_status[rx - 1] === 0) {
      for (let n of ogps[rx - 1])
        if (n) sendCommand(get_ip(rx1ip4, n), "set_hdmiout+on", null);

      rx_output_status[rx - 1] = 1;
    }
  }
  else {
    for (let n of ogps[rx - 1])
      if (n) sendCommand(get_ip(rx1ip4, n), "set_hdmiout+off", null);

    rx_output_status[rx - 1] = 0;
  }
  setChannelLabel(rx, ch);
}

function setChannel(rx) {
  if (wall_member[rx - 1]) {
    for (let i = 0; i < 10; i++)
      if (wall_member[i])
        setCH(i + 1, input);
  }
  else {
    setCH(rx, input);
  }
}

function setAllChannel() {
  for (let i = 1; i <= number_of_ogps; i++) {
    setCH(i, input);
  }
}

function getChannel(n, callback) {
  let rx = ogps[n - 1][0];
  let ip = get_ip(rx1ip4, rx);
  console.log("getChannel(): " + n + ", " + rx);

  if (suppress_send_command(ip)){console.log("command suppressed");callback(1);return;}

  sendCommand(ip, "get_hdmiout", function (result) {
    if (result.replace(/\n\r/g, "") === "off")
      callback(0);
    else
      sendCommand(ip, "get_channel", function (result) {
        let ch = Number(result.replace(/\n\r/g, ""));
        callback(ch);
      });
  });
}

function scanRXs() {
  for (let i = 1; i <= number_of_ogps; i++) {
    getChannel(i, function (ch) {
      console.log("getChannel() callback, i:" + i + ", ch: " + ch);
      setChannelLabel(i, ch)
    });
  }
}

function setLabels() {
  console.log("setLabels()");

  /* Delete un-nesseary rows. row_all and presets goes up. */
  for (let i = Math.max(number_of_txs, number_of_ogps); i < btnrows; i++) {
    let div = document.getElementById("div_" + (i+1) + "_0");
    div.style.display = "none";
  }

  /* Show or hide input buttuns */
  for (let i = 0; i < btnrows; i++) {
    let div = document.getElementById("div_" + (i+1) + "_1");
    let lbl = document.getElementById("label_in_" + (i+1));
    if (i < number_of_txs) {
      lbl.textContent = inputs[i];
      div.style.visibility = "visible";
    }
    else {
      div.style.visibility = "hidden";
    }
  }

  /* Show or hide output buttuns */
  for (let i = 0; i < btnrows; i++) {
    let div2 = document.getElementById("div_" + (i+1) + "_2");
    let div3 = document.getElementById("div_" + (i+1) + "_3");
    let btn  = document.getElementById("btn_out_" + (i+1));
    if (i < number_of_ogps) {
      btn.textContent = outputs[i];
      div2.style.visibility = "visible";
      div3.style.visibility = "visible";
    }
    else {
      div2.style.visibility = "hidden";
      div3.style.visibility = "hidden";
    }
  }

  /* Show row_all. This row was never hidden. */
  document.getElementById("div_all_0").style.visibility = "visible";

  /* Show or hide preset buttuns */
  for (let i = 0; i < number_of_presets; i++) {
    let btn = document.getElementById("btn_p" + (i+1));
    if ((btn.textContent = preset_label[i]) === "")
      btn.style.visibility = "hidden";
    else
      btn.style.visibility = "visible";
  }
}

function setPresetLabel(n, lbl) {
  document.getElementById("btn_p" + n).textContent = lbl;
}

function setValues() {
  document.getElementById("inp_rx_ipaddr").value = get_ip(rx1ip4, 1);
  document.getElementById("inp_tx_ipaddr").value = get_ip(tx1ip4, 1);
  document.getElementById("inp_channel").value = tx1ch;
  document.getElementById("inp_lkey").value = git_commith;
}

function getScreenSize() {
  console.log("sw: " + window.parent.screen.width);
  console.log("sh: " + window.parent.screen.height);
  console.log("ww: " + window.innerWidth);
  console.log("wh: " + window.innerHeight);
  console.log("h/w: " + window.innerHeight / window.innerWidth);
}

document.addEventListener('init', function(event) {
  let page = event.target;
 
  if (page.id === 'page1') {
    console.log("init page1");
    setLabels();
    scanRXs();
    getScreenSize();

    page.querySelector('#toolbar-button').onclick = function() {
      document.querySelector('#myNavigator')
        .pushPage('page2.html', {data: {title: 'メニュー'}});
    };
  } else if (page.id === 'page2') {
    page.querySelector('ons-toolbar .center').innerHTML = page.data.title;

    console.log("init page2");
    setValues();
  } 
});

document.addEventListener('show', function(event) {
  let page = event.target;
 
  if (page.id === 'page1') {
    console.log("show page1");
  } else if (page.id === 'page2') {
    console.log("show page2");
  }
});

// Application Cache ////////////////////////////////////////////////

let no_update_alert = 0;

// From ver.70 Chrome will not allow applicationCache on http.
// Only https could be supported for applicationCache.
// Hope Safari would support http longer peried. 
const appCachErrorMessage = 'Do you use Chrome? AppCache Disabled!!';

if (window.applicationCache == null) {
  // alert(appCachErrorMessage);
  console.log(appCachErrorMessage);
}
else {
  window.applicationCache.addEventListener("updateready", function() {
    console.log("applicationCache updateready");

    alert('AppCache updates available.');
    no_update_alert = 0;
    localStorage.clear();
    window.applicationCache.swapCache();
    window.location.reload();
  });

  window.applicationCache.addEventListener("obsolete", function() {
    console.log("applicationCache obsolete");
    alert("404/410 for manifest\nCache obsolete");
  });

  window.applicationCache.addEventListener("downloading", function() {
    console.log("applicationCache downloading");
    alert('AppCache downloading');
  });

  window.applicationCache.addEventListener("noupdate", function() {
    console.log("applicationCache noupdate");
    if (no_update_alert) {
      alert("There is no update");
      no_update_alert = 0;
    }
  });

  window.applicationCache.addEventListener("error", function() {
    console.log("applicationCache error");
    if (no_update_alert) {
      alert("Cannot download cache manifest");
      no_update_alert = 0;
    }
  });
} 

function updateAppCache() {
  if (!appCacheEnabled) {
    console.log("appCach disabled");
    return;
  }
  if (window.applicationCache == null) {
    alert(appCachErrorMessage);
    console.log(appCachErrorMessage);
    return;
  }

  let path = location.pathname;
  console.log("updateAppCache(), " + path);
  alert("Checking updates for \n" + path);
  no_update_alert = 1;
  window.applicationCache.update();
}
